'use client';

import React, {
    forwardRef,
    useEffect,
    useImperativeHandle,
    useRef,
} from 'react';
import { bool, string } from 'prop-types';
import { InputLayoutProps } from './input-layout.types';

export const InputLayout = forwardRef<HTMLInputElement, InputLayoutProps>(
    ({ indeterminate, typeInput, type, ...props }, ref) => {
        const checkboxRef = useRef<HTMLInputElement>(null);

        useEffect(() => {
            checkboxRef.current.indeterminate = indeterminate === true;
        }, []);

        useImperativeHandle(ref, () => checkboxRef.current);

        const classesType = typeInput || type;

        const extraClassStyles =
            props.className !== undefined
                ? `m3 m3-${type} ${props.className}`
                : `m3 m3-${classesType}`;

        return (
            <input
                ref={checkboxRef}
                {...props}
                className={extraClassStyles.trimEnd()}
                type={type}
            />
        );
    },
);

InputLayout.propTypes = {
    typeInput: string,
    indeterminate: bool,
};
